@@ -35,11 +35,11 @@ void
 edit_menu_set_sensitivity (gboolean flag)
 {
     static gboolean sensitivity = TRUE;
-    gint i, items[2] = {4, 6};
+    gint i, items[4] = {0, 1, 4, 6};
     
     if (! (sensitivity ^ flag))
 	return;
-    for (i=0; i < 2; i++) {
+    for (i=0; i < 4; i++) {
        sensitivity = flag;
        gtk_widget_set_sensitive (GTK_WIDGET (edit_menu[items[i]].widget), flag);
     }
@@ -216,7 +216,7 @@ main_app_create_ui (MainApp *app)
         gnome_app_set_statusbar (GNOME_APP (app->window), appbar);
         gtk_widget_show (appbar);
 
-        gnome_app_create_menus (GNOME_APP (app->window), menubar);
+        gnome_app_create_menus_with_data (GNOME_APP (app->window), menubar, app->window);
 	edit_menu_set_sensitivity (FALSE);
 
         gnome_app_install_menu_hints (GNOME_APP (app->window), menubar);
@@ -246,6 +246,8 @@ main_app_create_ui (MainApp *app)
         app->entry = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (alabel), app->entry);
         gtk_box_pack_start (GTK_BOX (hbox), app->entry, TRUE, TRUE, 0);
+	g_signal_connect (G_OBJECT (GTK_EDITABLE (app->entry)), "changed",
+			  G_CALLBACK (cb_entry_changed), NULL);
         
 	button = gtk_button_new ();
 	if (GTK_BIN (button)->child)
