@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.56 2002/06/01 21:32:46 gman Exp $ */
+/* $Id: gdict-app.c,v 1.57 2002/06/05 03:08:06 jirka Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -732,7 +732,7 @@ static GnomeUIInfo help_menu_uiinfo[] = {
 };
 
 static GnomeUIInfo menubar_uiinfo[] = {
-    { GNOME_APP_UI_SUBTREE_STOCK, N_("_Dictionary"), NULL, 
+    { GNOME_APP_UI_SUBTREE, N_("_Dictionary"), NULL, 
       dictionary_menu_uiinfo, NULL, NULL, (GnomeUIPixmapType) 0, 
       NULL, 0, (GdkModifierType) 0, NULL },
     GNOMEUIINFO_MENU_EDIT_TREE (edit_menu_uiinfo),
